<?php
/* $Id: norwegian-utf-8.inc.php,v 2.157.2.1 2006/08/26 14:00:37 lem9 Exp $ */

/**
 * Translated by Sven-Erik Andersen <sven DOT erik DOT andersen AT gmail DOT com>
 */

$charset = 'utf-8';
$allow_recoding = TRUE;
$text_dir = 'ltr';
$number_thousands_separator = '.';
$number_decimal_separator = ',';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits = array('Bytes', 'B', 'KiB', 'MiB', 'GiB', 'TiB', 'PiB', 'EiB');

$day_of_week = array('Søn', 'Man', 'Tir', 'Ons', 'Tor', 'Fre', 'Lør');
$month = array('Jan', 'Feb', 'Mar', 'Apr', 'Mai', 'Jun', 'Jul', 'Aug', 'Sep', 'Okt', 'Nov', 'Des');
// See http://www.php.net/manual/en/function.strftime.php to define the
// variable below
$datefmt = '%d. %B, %Y klokka %H:%M %p';
$timespanfmt = '%s dager, %s timer, %s minutter og %s sekunder';

$strAbortedClients = 'Avbrutt';
$strAbsolutePathToDocSqlDir = 'Vennligst skriv inn den absolutte stien på webtjeneren til docSQL katalogen';
$strAccessDeniedCreateConfig = 'En mulig årsak for dette er at du ikke opprettet konfigurasjonsfila. Du bør kanskje bruke %1$ssetup script%2$s for å opprette en.';
$strAccessDeniedExplanation = 'phpMyAdmin forsøkte å koble til MySQL-serveren, og serveren avviste tilkoblingen. Du må kontrollere vert (host), brukernavn (username) og passord (password) i config.inc.php og sjekke at de tilsvarer den informasjonen du fikk fra MySQL-server administratoren.';
$strAccessDenied = 'Ingen tilgang';
$strAction = 'Handling';
$strAddAutoIncrement = 'Legg til AUTO_INCREMENT verdi';
$strAddClause = 'Legg til %s';
$strAddConstraints = 'Legg til begrensninger';
$strAddDeleteColumn = 'Legg til/Slett kolonne';
$strAddDeleteRow = 'Legg til/Slett kriterierad';
$strAddedColumnComment = 'Lagt til kolonnekommentar';
$strAddedColumnRelation = 'Lagt til relasjon for kolonne';
$strAddFields = 'Legg til %s felt(er)';
$strAddHeaderComment = 'Legg til egen kommentar i hodet (\\n lager linjeskift)';
$strAddIntoComments = 'Legg til i kommentarer';
$strAddNewField = 'Legg til felt';
$strAddPrivilegesOnDb = 'Legg til privilegier til følgende database';
$strAddPrivilegesOnTbl = 'Legg til privilegier til følgende tabell';
$strAddSearchConditions = 'Legg til søkekriterier (innhold i "where"-setningen):';
$strAddToIndex = 'Legg til indeks&nbsp;%s&nbsp;kolonne(r)';
$strAddUser = 'Legg til en ny bruker';
$strAddUserMessage = 'Du har lagt til en ny bruker.';
$strAdministration = 'Administrasjon';
$strAffectedRows = 'Berørte rader:';
$strAfter = 'Etter %s';
$strAfterInsertBack = 'Returner';
$strAfterInsertNewInsert = 'Sett inn en ny post';
$strAfterInsertNext = 'Rediger neste rad';
$strAfterInsertSame = 'Tilbake til denne siden';
$strAll = 'Alle';
$strAllowInterrupt = 'Tillat avbrudd av importering i tilfelle skriptet oppdager at det er rett før det når tidsavbrudd. Dette kan være en god måte å importere store filer på, men det kan knekke transaksjoner.';
$strAllTableSameWidth = 'vis alle tabeller med samme bredde?';
$strAlterOrderBy = 'Endre tabellrekkefølge ved';
$strAnalyzeTable = 'Analyser tabell';
$strAnd = 'og';
$strAndThen = 'og så';
$strAnIndex = 'En indeks har blitt lagt til %s';
$strAny = 'Alle';
$strAnyHost = 'Alle verter';
$strAnyUser = 'Alle brukere';
$strApproximateCount = 'Kan være unøyaktig. Se FAQ 3.11';
$strAPrimaryKey = 'En primærnøkkel har blitt lagt til %s';
$strArabic = 'arabisk';
$strArmenian = 'armensk';
$strAscending = 'Stigende';
$strAtBeginningOfTable = 'Ved begynnelsen av tabellen';
$strAtEndOfTable = 'Ved slutten av tabellen';
$strAttr = 'Attributter';
$strAutodetect = 'Automatisk oppdaging';
$strAutomaticLayout = 'Automatisk disposisjon';

$strBack = 'Tilbake';
$strBaltic = 'baltisk';
$strBeginCut = 'START KUTT';
$strBeginRaw = 'START UFORMATERT';
$strBinary = ' Binær ';
$strBinaryDoNotEdit = ' Binær - må ikke redigeres ';
$strBinaryLog = 'Binærlogg';
$strBinLogEventType = 'Hendelsestype';
$strBinLogInfo = 'Informasjon';
$strBinLogName = 'Loggnavn';
$strBinLogOriginalPosition = 'Original posisjon';
$strBinLogPosition = 'Posisjon';
$strBinLogServerId = 'Tjener ID';
$strBookmarkAllUsers = 'La alle brukere ha adgang til dette bokmerket';
$strBookmarkCreated = 'Bokmerke %s opprettet';
$strBookmarkDeleted = 'Bokmerket har blitt slettet.';
$strBookmarkLabel = 'Navn';
$strBookmarkQuery = 'Lagret SQL-spørring';
$strBookmarkReplace = 'Erstatt eksisterende bokmerke med samme navn';
$strBookmarkThis = 'Lagre denne SQL-spørringen';
$strBookmarkView = 'Bare se';
$strBrowseDistinctValues = 'Se gjennom distinkte verdier';
$strBrowseForeignValues = 'Se de eksterne verdiene';
$strBrowse = 'Se på';
$strBufferPoolActivity = 'Mellomlageraktivitet';
$strBufferPool = 'Mellomlager';
$strBufferPoolUsage = 'Mellomlagerbruk';
$strBufferReadMissesInPercent = 'Lesebommer i %';
$strBufferReadMisses = 'Lesebommer';
$strBufferWriteWaitsInPercent = 'Skriveforsinkelser i %';
$strBufferWriteWaits = 'Skriveforsinkelser';
$strBulgarian = 'bulgarsk';
$strBusyPages = 'Opptatte sider';
$strBzError = 'phpMyAdmin kunne ikke komprimere dumpede data fordi Bz2 tillegget til denne php versjonen er ødelagt. Vi anbefaler på det sterkeste at du setter <code>$cfg[\'BZipDump\']</code> direktivet i din phpMyAdmin konfigurasjonsfil til <code>FALSE</code>. Hvis du ønsker å bruke Bz2 komprimerings funksjonene, så bør du oppgradere til en nyere php versjon. Se php bug rapport %s for detaljer.';
$strBzip = 'Komprimert (bz2)';

$strCalendar = 'Kalender';
$strCanNotLoadExportPlugins = 'Kunne ikke laste eksporttillegg, kontroller din innstallasjon!';
$strCanNotLoadImportPlugins = 'Kan ikke starte importeringsprogramtilleggene, kontroller din installasjon!';
$strCannotLogin = 'Kan ikke logge inn til MySQL tjeneren';
$strCantLoad = 'Kan ikke starte %s tillegget,<br />vennligst kontroller PHP-konfigurasjonen';
$strCantLoadRecodeIconv = 'Kan ikke laste iconv- eller recode-modulen som trengs for tegnsett konvertering, konfigurer php slik at disse kan lastes eller slå av tegnsettkonvertering i phpMyAdmin.';
$strCantRenameIdxToPrimary = 'Kan ikke endre indeks til PRIMARY!';
$strCantUseRecodeIconv = 'Kan ikke bruke hverken iconv, libiconv eller recode_string funksjonene selv om modulene sier de er lastet. Sjekk din php-konfigurasjon.';
$strCardinality = 'Kardinalitet';
$strCaseInsensitive = 'uavhengig av bokstavstørrelse';
$strCaseSensitive = 'avhengig av bokstavstørrelse';
$strCentralEuropean = 'sentraleuropeisk';
$strChangeCopyModeCopy = '... behold den gamle.';
$strChangeCopyModeDeleteAndReload = ' ... slett den gamle fra brukertabellene og deretter oppfrisk privilegiene.';
$strChangeCopyModeJustDelete = ' ... slett den gamle fra brukertabellene.';
$strChangeCopyMode = 'Opprett ny bruker med de samme privilegier og ...';
$strChangeCopyModeRevoke = ' ... tilbakekall alle aktive privilegier fra den gamle og slett den etterpå.';
$strChangeCopyUser = 'Endre innloggingsinformasjon / kopiere bruker';
$strChangeDisplay = 'Velg felt for visning';
$strChange = 'Endre';
$strChangePassword = 'Endre passord';
$strCharsetOfFile = 'Filens tegnsett:';
$strCharsetsAndCollations = 'Tegnsett og sammenligninger';
$strCharsets = 'Tegnsett';
$strCharset = 'Tegnsett';
$strCheckAll = 'Merk alle';
$strCheckOverhead = 'Kontroller overheng';
$strCheckPrivs = 'Kontroller privilegier';
$strCheckPrivsLong = 'Kontroller privilegier for databasen &quot;%s&quot;.';
$strCheckTable = 'Kontroller tabell';
$strChoosePage = 'Vennligst velg en side for redigering';
$strColComFeat = 'Vis kolonnekommentarer';
$strCollation = 'Sammenligning';
$strColumnNames = 'Kolonnenavn';
$strColumnPrivileges = 'Kolonne-spesifikke privilegier';
$strCommand = 'Kommando';
$strCommentsForTable = 'TABELLKOMMENTARER';
$strComments = 'Kommentarer';
$strCompatibleHashing = 'MySQL&nbsp;4.0 kompatibel';
$strCompleteInserts = 'Komplette innlegg';
$strCompression = 'Kompresjon';
$strCompressionWillBeDetected = 'Komprimering av importerte filer vil bli automatisk oppdaget fra: %s';
$strConfigDefaultFileError = 'Kunne ikke laste standard konfigurasjonsfil fra: "%1$s"';
$strConfigFileError = 'phpMyAdmin kunne ikke lese din konfigurasjonsfil!<br />Dette kan skje hvis PHP finner en syntaksfeil eller ikke kan finne filen.<br />Vennligst kall opp konfigurasjonsfilen direkte via linken under og les PHP feilmeldingen(e) som du vil få. I de fleste tilfeller så mangler det et anførselstegn eller et semikolon et sted.<br />Hvis du får en blank side så er alt ok.';
$strConfigureTableCoord = 'Vennligst konfigurer koordinatene for tabell %s';
$strConnectionError = 'Kan ikke koble til: ugyldige innstillinger.';
$strConnections = 'tilkoblinger';
$strConstraintsForDumped = 'Begrensninger for dumpede tabeller';
$strConstraintsForTable = 'Begrensninger for tabell';
$strCookiesRequired = 'Cookies må være slått på forbi dette punkt.';
$strCopyDatabaseOK = 'Databasen %s har blitt kopiert til %s';
$strCopy = 'Kopier';
$strCopyTable = 'Kopier tabell til (database<b>.</b>tabell):';
$strCopyTableOK = 'Tabellen %s er kopiert til %s.';
$strCopyTableSameNames = 'Kan ikke kopiere tabellen til samme navn!';
$strCouldNotKill = 'phpMyAdmin kunne ikke avslutte tråd %s. Den er sansynligvis alt avsluttet.';
$strCreateDatabaseBeforeCopying = 'CREATE DATABASE før kopiering';
$strCreateIndex = 'Lag en indeks på&nbsp;%s&nbsp;kolonner';
$strCreateIndexTopic = 'Lag en ny indeks';
$strCreateNewDatabase = 'Opprett ny database';
$strCreateNewTable = 'Opprett ny tabell i database %s';
$strCreate = 'Opprett';
$strCreatePage = 'Lag en ny side';
$strCreatePdfFeat = 'Lag PDF-dokumenter';
$strCreateUserDatabase = 'Brukerdatabase';
$strCreateUserDatabaseName = 'Opprett database med samme navn og gi alle rettigheter';
$strCreateUserDatabaseNone = 'Ingen';
$strCreateUserDatabaseWildcard = 'Gi alle rettigheter på jokertegnavn (username_%)';
$strCreationDates = 'Opprettelse/Oppdaterings/Kontrolldato';
$strCriteria = 'Kriterier';
$strCroatian = 'kroatisk';
$strCSV = 'CSV';
$strCSVImportOptions = 'CSV innstillinger';
$strCSVOptions = 'CSV valg';
$strCyrillic = 'kyrillisk';
$strCzechSlovak = 'Tjekkoslovakisk';
$strCzech = 'tjekkisk';

$strDanish = 'dansk';
$strDatabase = 'Database';
$strDatabaseEmpty = 'Databasen er uten navn!';
$strDatabaseExportOptions = 'Databaseeksportinnstillinger';
$strDatabaseHasBeenDropped = 'Databasen %s har blitt slettet';
$strDatabaseNoTable = 'Denne databasen har ingen tabeller!';
$strDatabases = 'databaser';
$strDatabasesDropped = '%s databasene har blitt slettet.';
$strDatabasesStatsDisable = 'Slå av statistikk';
$strDatabasesStatsEnable = 'Slå på statistikk';
$strDatabasesStatsHeavyTraffic = 'OBS: Når du slår på databasestatistikk så kan det medføre stor traffik mellom webtjeneren og MySQL-tjeneren.';
$strDatabasesStats = 'Statistikk for databaser';
$strData = 'Data';
$strDataDict = 'Dataordbok';
$strDataOnly = 'Bare data';
$strDataPages = 'Sider som inneholder data';
$strDBComment = 'Database kommentar: ';
$strDBCopy = 'Kopier databasen til';
$strDBGContextID = 'Sammenhengs-ID';
$strDBGContext = 'Sammenheng';
$strDBGHits = 'Treff';
$strDBGLine = 'Linje';
$strDBGMaxTimeMs = 'Max tid, ms';
$strDBGMinTimeMs = 'Min tid, ms';
$strDBGModule = 'Modul';
$strDBGTimePerHitMs = 'Tid/Treff, ms';
$strDBGTotalTimeMs = 'Total tid, ms';
$strDbPrivileges = 'Databasespesifikke privilegier';
$strDBRename = 'Endre databasens navn til';
$strDbSpecific = 'databasespesifikk';
$strDefaultEngine = '%s er standard lagringsmotor for denne MySQL tjeneren.';
$strDefault = 'Standard';
$strDefaultValueHelp = 'Sett inn en enkelt verdi for standard verdier uten skråstrek, anførselstegn eller annen &quot;escaping&quot; med dette formatet: a';
$strDefragment = 'Defragmenter tabell';
$strDelayedInserts = 'Bruk forsinkede innsettinger';
$strDeleteAndFlushDescr = 'Dette er den beste måten, men oppfrisking av privilegiene kan ta litt tid.';
$strDeleteAndFlush = 'Slett brukeren og oppfrisk privilegiene etterpå.';
$strDeleted = 'Raden er slettet';
$strDeletedRows = 'Slettede rader:';
$strDeleteNoUsersSelected = 'Ingen brukere merket for sletting!';
$strDelete = 'Slett';
$strDeleting = 'Sletter %s';
$strDelimiter = 'Skilletegn';
$strDelOld = 'Den nåværende siden har referanser til tabeller som ikke lenger eksisterer. Vil du slette disse referansene?';
$strDescending = 'Synkende';
$strDescription = 'Beskrivelse';
$strDictionary = 'ordbok';
$strDirtyPages = 'Endrede sider';
$strDisabled = 'Avslått';
$strDisableForeignChecks = 'Slå av kontroll av fremmednøkler';
$strDisplayFeat = 'Vis egenskaper';
$strDisplayOrder = 'Visningsrekkefølge:';
$strDisplayPDF = 'Vis PDF-skjema';
$strDoAQuery = 'Utfør en "spørring ved eksempel" (jokertegn: "%")';
$strDocu = 'Dokumentasjon';
$strDoYouReally = 'Vil du virkelig ';
$strDropDatabaseStrongWarning = 'Du er i ferd med å SLETTE en komplett database!';
$strDrop = 'Slett';
$strDropUsersDb = 'Slett databasene som har det samme navnet som brukerne.';
$strDumpingData = 'Dataark for tabell';
$strDumpSaved = 'Dump har blitt lagret til fila %s.';
$strDumpXRows = 'Dumpe %s rader fra rad %s.';
$strDynamic = 'dynamisk';

$strEdit = 'Endre';
$strEditPDFPages = 'Rediger PDF-sider';
$strEditPrivileges = 'Rediger privilegier';
$strEffective = 'Effektiv';
$strEmptyResultSet = 'MySQL returnerte ett tomt resultat (m.a.o. ingen rader).';
$strEmpty = 'Tøm';
$strEnabled = 'Påslått';
$strEncloseInTransaction = 'Inneslutt eksport i en transaksjon';
$strEndCut = 'STOPP KUTT';
$strEndRaw = 'STOPP UFORMATERT';
$strEnd = 'Slutt';
$strEngineAvailable = '%s er tilgjengelig på denne MySQL theneren.';
$strEngineDisabled = '%s har blitt dekativert for denne MySQL tjeneren.';
$strEngines = 'Motorer';
$strEngineUnsupported = 'Denne MySQL tjeneren har ikke støtte for %s lagringsmotoren.';
$strEnglish = 'engelsk';
$strEnglishPrivileges = 'OBS: MySQL privilegiumnavn er på engelsk';
$strError = 'Feil';
$strErrorInZipFile = 'Feil i ZIP arkivet:';
$strErrorRenamingTable = 'Feil oppstond med endring av tabellnavn fra %1$s til %2$s';
$strEscapeWildcards = 'Jokertegnene _ og % må beskyttes med en \ for å bruke dem direkte';
$strEsperanto = 'Esperanto';
$strEstonian = 'estisk';
$strExcelEdition = 'Excel-versjon';
$strExcelOptions = 'Excel-innstillinger';
$strExecuteBookmarked = 'Utfør lagret spørring';
$strExplain = 'Forklar SQL';
$strExport = 'Eksporter';
$strExportMustBeFile = 'Valgte eksporteringstype krever lagring til ei fil!';
$strExtendedInserts = 'Utvidete innlegg';
$strExtra = 'Ekstra';

$strFailedAttempts = 'Feilede forsøk';
$strField = 'Felt';
$strFieldHasBeenDropped = 'Feltet %s har blitt slettet';
$strFieldsEmpty = ' Antall felter er tommt! ';
$strFieldsEnclosedBy = 'Felter omsluttet av';
$strFieldsEscapedBy = 'Felter beskyttet med';
$strFields = 'Felter';
$strFieldsTerminatedBy = 'Felter avsluttet med';
$strFileAlreadyExists = 'Fila %s eksisterer alt på serveren, endre navnet eller merk av for overskriving av fil.';
$strFileCouldNotBeRead = 'Fila kunne ikke leses';
$strFileNameTemplateDescriptionDatabase = 'databasenavn';
$strFileNameTemplateDescription = 'Denne verdien blir tolket slik som %1$sstrftime%2$s, så du kan bruke tidformateringsstrenger. I tillegg vil følgende transformasjoner skje: %3$s. All annen tekst beholdes som den er.';
$strFileNameTemplateDescriptionServer = 'tjenernavn';
$strFileNameTemplateDescriptionTable = 'tabellnavn';
$strFileNameTemplate = 'Filnavnsmal';
$strFileNameTemplateRemember = 'husk malen';
$strFileToImport = 'Fil for importering';
$strFixed = 'statisk';
$strFlushPrivilegesNote = 'Merk: phpMyAdmin får brukerprivilegiene direkte fra MySQL privilegietabeller. Innholdet i disse tabellene kan være forskjellig fra de privilegiene tjeneren bruker hvis det er utført manuelle endringer på den. I så fall bør du %soppfriske privilegiene%s før du fortsetter.';
$strFlushQueryCache = 'Flush query cache';
$strFlushTable = 'Oppfrisk tabellen ("FLUSH")';
$strFlushTables = 'Flush (close) all tables';
$strFontSize = 'Fontstørrelse';
$strFormat = 'Format';
$strFormEmpty = 'Manglende verdi i skjemaet!';
$strFreePages = 'Ledige sider';
$strFullText = 'Hele strenger';
$strFunction = 'Funksjon';
$strFunctions = 'Funsjoner';

$strGenBy = 'Generert av';
$strGeneralRelationFeat = 'Generelle relasjonsegenskaper';
$strGenerate = 'Generer';
$strGeneratePassword = 'Generer passord';
$strGenTime = 'Generert den';
$strGeorgian = 'Georgisk';
$strGerman = 'tysk';
$strGlobal = 'global';
$strGlobalPrivileges = 'Globale privilegier';
$strGlobalValue = 'Global verdi';
$strGo = 'Utfør';
$strGrantOption = 'Rettighet';
$strGreek = 'gresk';
$strGzip = 'Komprimert (gz)';

$strHandler = 'Handler';
$strHasBeenAltered = 'er endret.';
$strHasBeenCreated = 'er opprettet.';
$strHaveToShow = 'Du må velge minst en kolonne for visning';
$strHebrew = 'hebraisk';
$strHexForBinary = 'Bruk heksadesimal for binære felter';
$strHome = 'Hjem';
$strHomepageOfficial = 'Offisiell phpMyAdmin-hjemmeside';
$strHostEmpty = 'Vertsnavnet er tomt!';
$strHost = 'Vert';
$strHTMLExcel = 'Microsoft Excel 2000';
$strHTMLExcelOptions = 'Microsoft Excel 2000 eksportinnstillinger';
$strHTMLWord = 'Microsoft Word 2000';
$strHTMLWordOptions = 'Microsoft Word 2000 eksportinnstillinger';
$strHungarian = 'ungarsk';

$strIcelandic = 'Islandsk';
$strId = 'ID';
$strIdxFulltext = 'Fulltekst';
$strIgnoreDuplicates = 'Ignorer dupliserte rader';
$strIgnore = 'Ignorer';
$strIgnoreInserts = 'Bruk ignore inserts';
$strIgnoringFile = 'Ignorerer fil %s';
$strImportDocSQL = 'Importer docSQL-filer';
$strImportFiles = 'Importer filer';
$strImportFormat = 'Formatet til importert fil';
$strImport = 'Importer';
$strImportSuccessfullyFinished = 'Importen er fullført, %d spørringer utført.';
$strIndexes = 'Indekser';
$strIndexHasBeenDropped = 'Indeksen %s har blitt slettet';
$strIndex = 'Indeks';
$strIndexName = 'Indeksnavn&nbsp;:';
$strIndexType = 'Indekstype&nbsp;:';
$strIndexWarningMultiple = 'Mer enn en %s nøkkel ble opprettet for kolonne `%s`';
$strIndexWarningPrimary = 'Både PRIMARY og INDEX nøkler bør ikke settes for kolonne `%s`';
$strIndexWarningTable = 'Problemer med indeksene i tabellen `%s`';
$strIndexWarningUnique = 'Både UNIQUE og INDEX nøkler bør ikke settes for kolonne `%s`';
$strInnoDBAutoextendIncrement = 'Autoforstørrende økning';
$strInnoDBAutoextendIncrementDesc = 'Økningen som brukes for å forstørre et autoforstørrende tabellager når den blir full.';
$strInnoDBBufferPoolSizeDesc = 'størrelsen på datalageret InnoDB bruker for å mellomlagre data og indekser for sine tabeller.';
$strInnoDBBufferPoolSize = 'Mellomlagerstørrelse';
$strInnoDBDataFilePath = 'Datafiler';
$strInnoDBDataHomeDir = 'Datalagringsmappe';
$strInnoDBDataHomeDirDesc = 'Felles del av filsti for alle InnoDB datafiler.';
$strInnoDBPages = 'sider';
$strInnodbStat = 'InnoDB status';
$strInsecureMySQL = 'Din konfigurasjonsfil inneholder innstillinger (root uten passord) som korrensponderer med MySQLs standard priviligerte brukerkonto. Din MySQL-tjener kjører med denne standardinnstillingen, er åpen for misbruk, og du burde fikse dette sikkerhetshullet snarest.';
$strInsertAsNewRow = 'Sett inn som ny rad';
$strInsertedRowId = 'Satt inn rad id:';
$strInsertedRows = 'Innsatte rader:';
$strInsert = 'Sett inn';
$strInternalNotNecessary = '* En intern relasjon er ikke nødvendig når den også eksisterer i InnoDB.';
$strInternalRelations = 'Interne relasjoner';
$strInUse = 'i bruk';
$strInvalidAuthMethod = 'Ugyldig autentiseringsmetode satt opp i konfigureringen:';
$strInvalidColumnCount = 'Antall kolonner må være større enn null.';
$strInvalidColumn = 'Ugyldig kollonne (%s) angitt!';
$strInvalidCSVFieldCount = 'Ugyldig antall felt i CSV importen i linje %d.';
$strInvalidCSVFormat = 'Ugyldig format i CSV importen i linje %d.';
$strInvalidCSVParameter = 'Ugyldig parameter for CSV import: %s';
$strInvalidDatabase = 'Ugylding database';
$strInvalidFieldAddCount = 'Du må sette inn minst ett felt.';
$strInvalidFieldCount = 'Tabellen må ha minst ett felt.';
$strInvalidLDIImport = 'Dette tillegget støtter ikke komprimerte importeringer!';
$strInvalidRowNumber = '%d er ikke et gyldig radnummer.';
$strInvalidServerHostname = 'Ugyldig tjenernavn for tjener %1$s. Kontroller din konfigurasjon.';
$strInvalidServerIndex = 'Ugyldig tjenerindeks: "%s"';
$strInvalidTableName = 'Ugylding tabellnavn';

$strJapanese = 'japansk';
$strJoins = 'Sammenføyninger';
$strJumpToDB = 'Hopp til databasen &quot;%s&quot;.';
$strJustDelete = 'Bare slett brukerne fra privilegium tabellene.';
$strJustDeleteDescr = 'Den &quot;slettede&quot; brukeren vil fortsatt kunne bruke tjeneren som normalt inntill privilegiene er oppfrisket.';

$strKeepPass = 'Ikke endre passordet';
$strKeyCache = 'Nøkkelmellomlager';
$strKeyname = 'Nøkkel';
$strKill = 'Avslutt';
$strKorean = 'koreansk';

$strLandscape = 'Landskapsformat';
$strLanguageFileNotFound = 'Språkfil "%1$s" ble ikke funnet.';
$strLanguage = 'Språk';
$strLanguageUnknown = 'Ukjent språk: %1$s.';
$strLatchedPages = 'Tilknyttede sider';
$strLatexCaption = 'Tabelloverskrift';
$strLatexContent = 'Innhold i tabell __TABLE__';
$strLatexContinuedCaption = 'Fortsettet tabelloverskrift';
$strLatexContinued = '(fortsettet)';
$strLatexIncludeCaption = 'Inkluder tabelloverskrift';
$strLatexLabel = 'Merkelappnøkkel';
$strLaTeX = 'LaTeX';
$strLaTeXOptions = 'LaTeX innstillinger';
$strLatexStructure = 'Struktur i tabell __TABLE__';
$strLatvian = 'Latvisk';
$strLDI = 'CSV med LOAD DATA';
$strLDIImportOptions = 'Innstillinger for CSV import via LOAD DATA';
$strLDILocal = 'Bruk LOCAL nøkkelord';
$strLengthSet = 'Lengde/Sett*';
$strLimitNumRows = 'Antall poster per side';
$strLinesTerminatedBy = 'Linker avsluttet med';
$strLinkNotFound = 'Link ikke funnet';
$strLinksTo = 'Linker til';
$strLithuanian = 'lithauisk';
$strLocalhost = 'Lokal';
$strLocationTextfile = 'Plassering av filen';
$strLoginInformation = 'Innlogingsinformasjon';
$strLogin = 'Logg inn';
$strLogout = 'Logg ut';
$strLogPassword = 'Passord:';
$strLogServer = 'Tjener';
$strLogUsername = 'Brukernavn:';
$strLongOperation = 'Denne operasjonen kan ta lang tid. Ønsker du å fortsette?';

$strMaxConnects = 'maks. samtidige tilkoblinger';
$strMaximalQueryLength = 'Maksimum lengde av opprettet spørring';
$strMaximumSize = 'Maksimum størrelse: %s%s';
$strMbExtensionMissing = 'PHP tillegget mbstring ble ikke funnet og det ser ut til at du bruker et flerbyte tegnsett. Uten mbstring-tillegget så kan ikke phpMyAdmin splitte strenger korrekt og dette kan medføre uønskede resultater.';
$strMbOverloadWarning = 'Du har slått på mbstring.func_overload i din PHP konfigurasjon. Denne opsjonen er ikke kompatibel med phpMyAdmin og kan medføre skader på data!';
$strMIME_available_mime = 'Tilgjengelige MIME-typer';
$strMIME_available_transform = 'Tilgjengelige transformationer';
$strMIME_description = 'Beskrivelse';
$strMIME_MIMEtype = 'MIME-type';
$strMIME_nodescription = 'Ingen beskrivelse er tilgjengelig for denne transformasjonen.<br />Spør forfatteren hva %s gjør.';
$strMIME_transformation = 'Nettvisertransformasjon';
$strMIME_transformation_note = 'For en liste over tilgjengelige transformasjonsvalg, klikk på %stransformasjonsbeskrivelser%s';
$strMIME_transformation_options_note = 'Skriv inn verdiene for transformasjon med dette formatet: \'a\',\'b\',\'c\'...<br />Hvis du trenger å bruke en skråstrek ("\") eller en enkel apostrof ("\'") blant disse verdiene så sett en skråstrek foran (eks. \'\\\\xyz\' eller \'a\\\'b\').';
$strMIME_transformation_options = 'Transformasjonsvalg';
$strMIMETypesForTable = 'MIME TYPER FOR TABELLEN';
$strMIME_without = 'MIME-typer skrevet i kursiv har ikke en separat transformasjonsfunksjon';
$strModifications = 'Endringene er lagret';
$strModify = 'Endre';
$strModifyIndexTopic = 'Endre en indeks';
$strMoveTable = 'Flytt tabell til (database<b>.</b>tabell):';
$strMoveTableOK = 'Tabellen %s har blitt flyttet til %s.';
$strMoveTableSameNames = 'Kan ikke flytte tabellen til samme navn!';
$strMultilingual = 'flerspråkelig';
$strMyISAMDataPointerSize = 'Datapekerstørrelse';
$strMyISAMDataPointerSizeDesc = 'Standard pekerstørrelse i bytes, som brukes av CREATE TABLE for MyISAM tabeller når ingen MAX_ROWS innstillinger er spesifisert.';
$strMyISAMMaxExtraSortFileSizeDesc = 'Hvis den midlertidige fila brukt for hurtig MyISAM indeksopprettelse ville bli større enn å bruke nøkkelmellomlager med størrelsen spesifisert her, så bruk nøkkellagermetoden.';
$strMyISAMMaxExtraSortFileSize = 'Maksimum størrelse for midlertidige filer under indeksopprettelse';
$strMyISAMMaxSortFileSizeDesc = 'Maksimum størrelse for den midlertidige fila MySQL har lov til å bruke når den gjennoppretter en MyISAM indeks (med spørringene REPAIR TABLE, ALTER TABLE, eller LOAD DATA INFILE).';
$strMyISAMMaxSortFileSize = 'Maksimum størrelse for midlertidige sorteringsfiler';
$strMyISAMRecoverOptions = 'Automatisk gjennopprettignsmodus';
$strMyISAMRecoverOptionsDesc = 'Modusen for automatisk gjennoppretting av MyISAM tabeller som har kræsjet, konfigurert via --myisam-recover tjeneroppstartsinnstillingen.';
$strMyISAMRepairThreadsDesc = 'Hvis denne verdien er større enn 1 så blir MyISAM tabellindekser opprettet parallelt (hver indeks i sin egen tråd) under REPAIR av sorteringsprosessen.';
$strMyISAMRepairThreads = 'Reparer tråder';
$strMyISAMSortBufferSizeDesc = 'Bufferet som brukes ved sortering av MyISAM indekser under en REPAIR TABLE eller når indekser blir opprettet med CREATE INDEX eller ALTER TABLE.';
$strMyISAMSortBufferSize = 'Sorteringsbufferstørrelse';
$strMySQLCharset = 'MySQL-tegnsett';
$strMysqlClientVersion = 'MySQL klientversjon';
$strMySQLConnectionCollation = 'Kollasjon av MySQL-oppkobling';
$strMySQLSaid = 'MySQL sa: ';
$strMySQLShowProcess = 'Vis prosesser';
$strMySQLShowStatus = 'Vis MySQL driftsstatus';
$strMySQLShowVars = 'Vis MySQL systemvariabler';

$strName = 'Navn';
$strNext = 'Neste';
$strNoActivity = 'Ingen aktivitet på %s sekunder eller mer, du må logge inn på nytt';
$strNoDatabases = 'Ingen databaser';
$strNoDatabasesSelected = 'Ingen databaser er valgt.';
$strNoDataReceived = 'Ingen data ble mottatt for importering. Enten ble ingen filnavn gitt, eller filstørrelsen oversteg maksimum størrelse tillatt i din PHP konfigurasjon. Se FAQ 1.16';
$strNoDescription = 'ingen beskrivelse';
$strNoDetailsForEngine = 'Det er ikke noen detaljert statusinformasjon for denne lagringsmotoren.';
$strNoDropDatabases = '"DROP DATABASE"-uttrykk er avslått.';
$strNoExplain = 'Ikke forklar SQL';
$strNoFilesFoundInZip = 'Ingen filer funnet inne i ZIP arkivet!';
$strNoFrames = 'phpMyAdmin er mer brukervennlig med en <b>rammekapabel</b> nettleser.';
$strNoIndex = 'Ingen indeks definert!';
$strNoIndexPartsDefined = 'Ingen indeksdeler definert!';
$strNoModification = 'Ingen endring';
$strNo = 'Nei';
$strNone = 'Ingen';
$strNoOptions = 'Dette formatet har ingen valg';
$strNoPassword = 'Intet passord';
$strNoPermission = 'Webserveren har ikke tillatelse til å lagre fila %s.';
$strNoPhp = 'uten PHP kode';
$strNoPrivileges = 'Ingen privilegier';
$strNoRights = 'Du har ikke nok rettigheter til å være her nå!';
$strNoRowsSelected = 'Ingen rader valgt';
$strNoSpace = 'Ikke nok plass til å lagre fila %s.';
$strNoTablesFound = 'Ingen tabeller i databasen.';
$strNoThemeSupport = 'Ikke støtte for maler, kontroller konfigureringen og/eller dine maler i katalogen %s.';
$strNotNumber = 'Dette er ikke ett tall!';
$strNotOK = 'ikke OK';
$strNotSet = '<b>%s</b> tabellen ble ikke funnet eller ikke konfigurert i %s';
$strNoUsersFound = 'Ingen bruker(e) funnet.';
$strNoValidateSQL = 'Ikke teste SQL';
$strNull = 'Null';
$strNumberOfFields = 'Antall felter';
$strNumSearchResultsInTable = '%s treff i tabell <i>%s</i>';
$strNumSearchResultsTotal = '<b>Totalt:</b> <i>%s</i> treff';
$strNumTables = 'Tabeller';

$strOK = 'OK';
$strOpenDocumentSpreadsheet = 'Open Document regneark';
$strOpenDocumentSpreadsheetOptions = 'Open Document regnearkinnstillinger';
$strOpenDocumentText = 'Open Document tekst';
$strOpenDocumentTextOptions = 'Open Document tekstinnstillinger';
$strOpenNewWindow = 'Åpne nytt phpMyAdmin vindu';
$strOperations = 'Operasjoner';
$strOperator = 'Operator';
$strOptimizeTable = 'Optimiser tabell';
$strOr = 'Eller';
$strOverhead = 'Overheng';
$strOverwriteExisting = 'Overskriv eksisterende fil(-er)';

$strPageNumber = 'Sidenummer:';
$strPagesToBeFlushed = 'Sider som skal tømmes';
$strPaperSize = 'Papirstørrelse';
$strPartialImport = 'Delvis importering';
$strPartialText = 'Delvis tekst';
$strPasswordChanged = 'Passordet til %s er endret.';
$strPasswordEmpty = 'Passordet er blankt!';
$strPasswordHashing = 'Passordnøkling';
$strPasswordNotSame = 'Passordene er ikke like!';
$strPassword = 'Passord';
$strPdfDbSchema = 'Skjema for "%s"-databasen - Side %s';
$strPdfInvalidTblName = 'Tabellen "%s" eksisterer ikke!';
$strPdfNoTables = 'Ingen tabeller';
$strPDFOptions = 'PDF innstillinger';
$strPDF = 'PDF';
$strPDFReportExplanation = '(Oppretter en rapport som inneholder dataene fra en enkel tabell)';
$strPDFReportTitle = 'Rapporttittel';
$strPerHour = 'per time';
$strPerMinute = 'per minutt';
$strPerSecond = 'per sekund';
$strPersian = 'Persisk';
$strPhoneBook = 'telefonkatalog';
$strPHP40203 = 'Du bruker PHP 4.2.3, som har en alvorlig feil med flerbyte-strenger (mbstring). Se PHP-feilrapport 19404. Denne versjonen av PHP er ikke anbefalt for bruk med phpMyAdmin.';
$strPhp = 'Lag PHP kode';
$strPHPVersion = 'PHP-Versjon';
$strPmaDocumentation = 'phpMyAdmin-Dokumentasjon';
$strPmaUriError = '<tt>$cfg[\'PmaAbsoluteUri\']</tt> variabelen MÅ være innstilt i din konfigurasjonsfil!';
$strPolish = 'Polsk';
$strPortrait = 'Portrettformat';
$strPos1 = 'Start';
$strPrevious = 'Forrige';
$strPrimaryKeyHasBeenDropped = 'Primærnøkkelen har blitt slettet';
$strPrimaryKeyName = 'Navnet til  primærnøkkelen må være... PRIMARY!';
$strPrimaryKeyWarning = '("PRIMARY" <b>må</b> være navnet til og <b>bare til</b> en primærnøkkel!)';
$strPrimary = 'Primær';
$strPrint = 'Skriv ut';
$strPrintViewFull = 'Forhåndsvisning (med all tekst)';
$strPrintView = 'Utskriftsvennlig forhåndsvisning';
$strPrivDescAllPrivileges = 'Inkluder alle privilegier unntatt GRANT.';
$strPrivDescAlterRoutine = 'Tillater endring og sletting av lagrede rutiner.';
$strPrivDescAlter = 'Tillater endring av struktur på eksisterende tabeller.';
$strPrivDescCreateDb = 'Tillater oppretting av nye databaser og tabeller.';
$strPrivDescCreateRoutine = 'Tillater oppreting av lagrede rutiner.';
$strPrivDescCreateTbl = 'Tillater oppretting av nye tabeller.';
$strPrivDescCreateTmpTable = 'Tillater oppretting av midlertidige tabeller.';
$strPrivDescCreateUser = 'Tillater oppretting, sletting og navneendring av brukerkontoer.';
$strPrivDescCreateView = 'Tillater oppretting av nye visninger.';
$strPrivDescDelete = 'Tillater sletting av data.';
$strPrivDescDropDb = 'Tillater sletting av databaser og tabeller.';
$strPrivDescDropTbl = 'Tillater sletting av tabeller.';
$strPrivDescExecute5 = 'Tillater utføring av lagrede rutiner.';
$strPrivDescExecute = 'Tillater kjøring av lagrede prosedyrer; har ingen effekt på denne versjonen av MySQL.';
$strPrivDescFile = 'Tillater import og eksport av data til og fra filer.';
$strPrivDescGrant = 'Tillater å legge til brukere og privilegier uten å oppfriske privilegietabellene.';
$strPrivDescIndex = 'Tillater oppretting og sletting av indekser.';
$strPrivDescInsert = 'Tillater å legge til og erstatte data.';
$strPrivDescLockTables = 'Tillater låsing av tabeller for den kjørende tråden.';
$strPrivDescMaxConnections = 'Begrenser antall nye tilkoblinger brukeren kan åpne per time.';
$strPrivDescMaxQuestions = 'Begrenser antall spørringer brukeren kan sende til tjeneren per time.';
$strPrivDescMaxUpdates = 'Begrenser antall kommandoer som kan endre tabeller eller databaser brukeren kan utføre per time.';
$strPrivDescMaxUserConnections = 'Begrens antall samtidige tilkoblinger brukeren kan ha.';
$strPrivDescProcess3 = 'Tillater avslutting av prosesser som tilhører andre brukere.';
$strPrivDescProcess4 = 'Tillater visning av komplette spørringer i prosesslisten.';
$strPrivDescReferences = 'har ingen effekt i denne versjonen av MySQL.';
$strPrivDescReload = 'Tillater oppfrisking av tjenerinnstillinger og oppfrisking av mellomlager.';
$strPrivDescReplClient = 'Gir tillatelse til brukeren til å spørre hvor replikasjonsslaver eller -tjenere er.';
$strPrivDescReplSlave = 'Trenges av replikasjonsslavene.';
$strPrivDescSelect = 'Tillater lesing av data.';
$strPrivDescShowDb = 'Gir adgang til komplett liste over databaser.';
$strPrivDescShowView = 'Tillater utføring av SHOW CREATE VIEW spørringer.';
$strPrivDescShutdown = 'Tillater avslutting av tjener.';
$strPrivDescSuper = 'Tillater tilkobling, selv om maksimum tilkoblinger er nådd. Behøves for de fleste administrative operasjoner som å sette globale variabler eller avslutting av andre brukeres tråder.';
$strPrivDescUpdate = 'Tillater endring av data.';
$strPrivDescUsage = 'Ingen privilegier.';
$strPrivileges = 'Privilegier';
$strPrivilegesReloaded = 'Oppfriskingen av privilegiene lyktes.';
$strProcedures = 'Prosedyrer';
$strProcesses = 'Prosesser';
$strProcesslist = 'Prosess liste';
$strProtocolVersion = 'Protokollversjon';
$strPutColNames = 'Sett inn feltnavn i første rad';

$strQBEDel = 'Slett';
$strQBEIns = 'Sett inn';
$strQBE = 'Spørring ved eksempel (Query by Example)';
$strQueryCache = 'Spørringsmellomlager';
$strQueryFrame = 'Spørringsvindu';
$strQueryOnDb = 'SQL-spørring i database <b>%s</b>:';
$strQueryResultsOperations = 'Spørringsresultatshandlinger';
$strQuerySQLHistory = 'SQL-historie';
$strQueryStatistics = '<b>Spørrings statistikk</b>: Siden oppstart, har %s spørringer blitt sendt til tjeneren.';
$strQueryTime = 'Spørring tok %01.4f sek';
$strQueryType = 'Spørringstype';
$strQueryWindowLock = 'Ikke overskriv denne spørringen fra andre vinduer';

$strReadRequests = 'Leseforespørsler';
$strReceived = 'Mottatt';
$strRecords = 'Rader';
$strReferentialIntegrity = 'Sjekk referanseintegritet:';
$strRefresh = 'Oppdater';
$strRelationalSchema = 'Relasjonsskjema';
$strRelationNotWorking = 'Tilleggsfunksjonene for å kunne jobbe med koblede tabeller er deaktivert. For å finne ut hvorfor, klikk %sher%s.';
$strRelationsForTable = 'RELASJONER FOR TABELLEN';
$strRelations = 'Relasjoner';
$strRelationView = 'Relasjonsvisning';
$strReloadingThePrivileges = 'Oppfrisker privilegiene';
$strReloadPrivileges = 'Oppfrisk privilegier';
$strRemoveSelectedUsers = 'Fjern valgte brukere';
$strRenameDatabaseOK = 'Databasen %s har endret navn til %s';
$strRenameTable = 'Endre tabellens navn';
$strRenameTableOK = 'Tabellen %s har fått nytt navn %s';
$strRepairTable = 'Reparer tabell';
$strReplaceNULLBy = 'Erstatt NULL med';
$strReplaceTable = 'Erstatt tabell med filen';
$strReplication = 'Replikering';
$strReset = 'Tøm skjema';
$strResourceLimits = 'Ressursbegrensninger';
$strReType = 'Gjenta';
$strRevokeAndDeleteDescr = 'Inntill privilegiene er oppfrisket vil brukerne fortsatt ha USAGE privilegiet.';
$strRevokeAndDelete = 'Tilbakekall alle aktive privilegier fra brukerne og slett dem etterpå.';
$strRevokeMessage = 'Du har fjernet privilegiene til %s';
$strRevoke = 'Tilbakekall';
$strRomanian = 'Rumensk';
$strRowLength = 'Radlengde';
$strRowsFrom = 'rader fra';
$strRowSize = ' Radstørrelse ';
$strRowsModeFlippedHorizontal = 'horisontal (roterte overskrifter)';
$strRowsModeHorizontal = 'vannrett';
$strRowsModeOptions = 'i %s modus og gjenta headers etter %s celler';
$strRowsModeVertical = 'loddrett';
$strRows = 'Rader';
$strRowsStatistic = 'Radstatistikk';
$strRunning = 'som kjører på %s';
$strRunQuery = 'Kjør spørring';
$strRunSQLQuery = 'Kjør SQL spørring/spørringer mot databasen %s';
$strRunSQLQueryOnServer = 'Kjør SQL spørring/spørringer på tjener %s';
$strRussian = 'russisk';

$strSave = 'Lagre';
$strSaveOnServer = 'Lagre på server i %s katalogen';
$strScaleFactorSmall = 'Skaleringsfaktoren er for liten til å romme alt på en side';
$strSearchFormTitle = 'Søk i database';
$strSearchInTables = 'I tabell(ene):';
$strSearchNeedle = 'Ord eller verdi(er) å søke etter (jokertegn: "%"):';
$strSearchOption1 = 'minst ett av ordene';
$strSearchOption2 = 'alle ordene';
$strSearchOption3 = 'med den nøyaktige setningen';
$strSearchOption4 = 'som "regular expression"';
$strSearchResultsFor = 'Søkeresultat for "<i>%s</i>" %s:';
$strSearch = 'Søk';
$strSearchType = 'Finn:';
$strSecretRequired = 'Konfigurasjonsfila trenger nå et hemmelig passordfrase (blowfish_secret).';
$strSelectADb = 'Vennligst velg en database';
$strSelectAll = 'Velg alle';
$strSelectBinaryLog = 'Velg binærlogg for visning';
$strSelectFields = 'Velg felt (minst ett):';
$strSelectNumRows = 'i spørring';
$strSelectTables = 'Velg tabeller';
$strSend = 'Last ned som fil';
$strSent = 'Sendt';
$strServerChoice = 'Tjenervalg';
$strServerNotResponding = 'Tjeneren svarer ikke';
$strServerStatusDelayedInserts = 'Forsinkede innsettinger';
$strServerStatus = 'Kjøringsinformasjon';
$strServerStatusUptime = 'Denne MySQL tjeneren har kjørt i %s. Den startet opp den %s.';
$strServers = 'Tjenere';
$strServerTabVariables = 'Variabler';
$strServer = 'Tjener';
$strServerTrafficNotes = '<b>Tjenertraffikk</b>: Disse tabellene viser statistikk over nettverkstrafikken for denne MySQL-tjeneren siden dens oppstart.';
$strServerVars = 'Tjenervariabler og -innstillinger';
$strServerVersion = 'Tjenerversjon';
$strSessionValue = 'Økts verdi';
$strSetEnumVal = 'Hvis felttypen er "enum" eller "set", skriv inn verdien med dette formatet: \'a\',\'b\',\'c\'...<br />Hvis du skulle trenge å ha en skråstrek ("\") eller en enkel apostrof ("\'") blant disse verdiene, skriv en skråstrek foran (eks. \'\\\\xyz\' eller \'a\\\'b\').';
$strShowAll = 'Vis alle';
$strShowColor = 'Vis farger';
$strShowDatadictAs = 'Data Ordbok Format';
$strShowFullQueries = 'Vis hele spørringen';
$strShowGrid = 'Vis rutenett';
$strShowingBookmark = 'Vis bokmerke';
$strShowingRecords = 'Viser rader ';
$strShowOpenTables = 'Vis åpne tabeller';
$strShowPHPInfo = 'Vis PHP-informasjon';
$strShowSlaveHosts = 'Vis slaveverter';
$strShowSlaveStatus = 'Vis slavestatus';
$strShowStatusBinlog_cache_disk_useDescr = 'Antall transaksjoner som brukte den midlertidige binærloggmellomlageret men som overskred verdien av binlog_size og brukte en midlertidig fil for å lagre spørringer fra transaksjonen.';
$strShowStatusBinlog_cache_useDescr = 'Antall transaksjoner som brukte den midlertidige binærloggmellomlageret.';
$strShowStatusCreated_tmp_disk_tablesDescr = 'Antall midlertidige tabeller lagret på harddisken automatisk opprettet av tjeneren mens den utførte spørringer. Hvis Created_tmp_disk_tables er stor bør du vurdere å øke tmp_table_size verdien slik at midlertidige tabeller blir lagret i minnet og ikke på harddisken.';
$strShowStatusCreated_tmp_filesDescr = 'Antall midlertidige filer mysqld har opprettet.';
$strShowStatusCreated_tmp_tablesDescr = 'Antall midlertidige tabeller i minnet automatisk opprettet av tjeneren under utføriing av spørringer.';
$strShowStatusDelayed_errorsDescr = 'Antall rader skrevet med INSERT DELAYED hvor en eller annen form for feil oppstod (mest sannsynlig duplisert nøkkel).';
$strShowStatusDelayed_insert_threadsDescr = 'Antall INSERT DELAYED håndterertråder i bruk. Hver eneste tabell hvor det blir brukt INSERT DELAYE får sin egen tråd.';
$strShowStatusDelayed_writesDescr = 'Antall INSERT DELAYED rader skrevet.';
$strShowStatusFlush_commandsDescr  = 'Antall utførte FLUSH uttrykk.';
$strShowStatusHandler_commitDescr = 'Antall interne COMMIT uttrykk.';
$strShowStatusHandler_deleteDescr = 'Antall ganger en rad ble slettet fra en tabell.';
$strShowStatusHandler_discoverDescr = 'MySQL tjeneren kan spørre NDB Cluster lagringsmotoren om den kjenner til en tabell med et gitt navn. Dette blir kalt oppdaging (discovery). Handler_discover indikerer antall ganger tabeller har blitt oppdaget.';
$strShowStatusHandler_read_firstDescr = 'Antall ganger det første innlegget ble lest fra en index. Hvis dette tallet er høyt tyder det på at tjeneren utfører en god del fullindekssøk; for eksempel, SELECT col1 FROM foo, da forutsatt at col1 er indeksert.';
$strShowStatusHandler_read_keyDescr = 'Antall forespørsler for å lese en rad basert på en nøkkel. Hvis dette tallet er høyt gir dette en god indikasjon på at dine spørringer og tabeller er riktig indeksert.';
$strShowStatusHandler_read_nextDescr = 'Antall forespørsler for å lese en rad basert på en fast posisjon. Denne er høy hvis du utører mange spørringer som behøver sortering av resultatet. Du har sansynligvis mange spørringer som krever at MySQL leser hele tabeller eller du har joins som ikke bruker nøkler korrekt.';
$strShowStatusHandler_read_prevDescr = 'Antall forespørsler for å lese den forrige raden i nøkkelrekkefølge. Denne lesemetoden er hovedsakelig brukt for å optimalisere ORDER BY ... DESC.';
$strShowStatusHandler_read_rndDescr = 'Antall forespørsler for å lese en rad basert på en fast posisjon. Denne er høy om du utfører mange spørringer som behøver sorteringer av resultatet. Du har mest sansynlig mange spørringer som krever at MySQL leser hele tabeller eller du har joins som som ikke bruker nøkler korrekt.';
$strShowStatusHandler_read_rnd_nextDescr = 'Antall forespørsler for å lese neste rad i datafila. Dette tallet er høyt hvis du utfører mange tabellskanninger. Vanligvis betyr dette at dine tabeller ikke er rett indeksert eller at dine spørringer ikke er skrevet for å utnytte de indeksene du har.';
$strShowStatusHandler_rollbackDescr = 'Antall interne ROLLBACK kommandoer.';
$strShowStatusHandler_updateDescr = 'Antall forespørsler for å oppdatere en rad i en tabell.';
$strShowStatusHandler_writeDescr = 'Antall forespørsler for å sette inn en rad i en tabell.';
$strShowStatusInnodb_buffer_pool_pages_dataDescr = 'Antall sider som inneholder data (endret eller uendret).';
$strShowStatusInnodb_buffer_pool_pages_dirtyDescr = 'Antall sider for tiden endret.';
$strShowStatusInnodb_buffer_pool_pages_flushedDescr = 'Antall midlertidige mellomlagersider som det har vært oppfriskningsforespørsler på.';
$strShowStatusInnodb_buffer_pool_pages_freeDescr = 'Antall tomme sider.';
$strShowStatusInnodb_buffer_pool_pages_latchedDescr = 'Antallet låste sider i InnoDBs mellomlager. Dette er sider som er under lesing eller skriving eller ikke kan tømmes eller fjernes av en annen grunn.';
$strShowStatusInnodb_buffer_pool_pages_miscDescr = 'Antall sider som er opptatt fordi de har blitt allokert for administrative oppgaver slik som radlåsing eller adaptiv nøkkelindeksering. Denne verdien kan også regnes ut som Innodb_buffer_pool_pages_total - Innodb_buffer_pool_pages_free - Innodb_buffer_pool_pages_data.';
$strShowStatusInnodb_buffer_pool_pages_totalDescr = 'Total størrelse på midlertidig mellomlager i sider.';
$strShowStatusInnodb_buffer_pool_read_ahead_rndDescr = 'Antall "tilfeldige" "read-aheads" InnoDB startet. Dette skjer når en spørring skanner en stor andel av en tabell men i en tilfeldig rekkefølge.';
$strShowStatusInnodb_buffer_pool_read_ahead_seqDescr = 'Antall sekvensielle "read-aheads" InnoDB startet. Denne skjer når InnoDB utfører en sekvensiell full tabellskanning.';
$strShowStatusInnodb_buffer_pool_read_requestsDescr = 'Antall logiske leseforespørsler InnoDB har utført.';
$strShowStatusInnodb_buffer_pool_readsDescr = 'Antall logiske lesninger som InnoDN ikke kunne tilfredsstille fra mellomlageret og måtte utføre en enkelsidelesnining.';
$strShowStatusInnodb_buffer_pool_wait_freeDescr = 'Normalt vil skrivinger til InnoDBs mellomlager skje i bakgrunnen. Men, hvis det er behov for å lese eller opprette en side og ingen rene/tomme sider er tilgjengelig så er det nødvendig å vente på at sider blir tømt først. Denne telleren viser antall slike ventinger. Hvis mellomlagerstørrelsen er godt innstilt så vil denne verdien være liten.';
$strShowStatusInnodb_buffer_pool_write_requestsDescr = 'Antall skrivinger til InnoDBs midlertidig mellomlager.';
$strShowStatusInnodb_data_fsyncsDescr = 'Antall fsync() operasjoner så langt.';
$strShowStatusInnodb_data_pending_fsyncsDescr = 'Antall ventende fsync() operasjoner.';
$strShowStatusInnodb_data_pending_readsDescr = 'Antall ventende lesinger.';
$strShowStatusInnodb_data_pending_writesDescr = 'Antall ventende skrivinger.';
$strShowStatusInnodb_data_readDescr = 'Mengden data lest så langt, i bytes.';
$strShowStatusInnodb_data_readsDescr = 'Antall utførte lesninger.';
$strShowStatusInnodb_data_writesDescr = 'Antall utførte skrivinger.';
$strShowStatusInnodb_data_writtenDescr = 'Mengden data skrevet så langt, i bytes.';
$strShowStatusInnodb_dblwr_pages_writtenDescr = 'Antallet dobbeltskrivinger som har blitt utført og antall sider som har blitt skrevet på grunn av dette.';
$strShowStatusInnodb_dblwr_writesDescr = 'Antallet dobbeltskrivinger som har blitt utført og antall sider som har blitt skrevet på grunn av dette.';
$strShowStatusInnodb_log_waitsDescr = 'Antall ganger ventinger vi hadde fordi loggmellomlageret var for lite og vi måtte vente for at det skulle bli tømt før vi kunne fortsette.';
$strShowStatusInnodb_log_write_requestsDescr = 'Antall loggskrivingsforespørsler.';
$strShowStatusInnodb_log_writesDescr = 'Antall fysiske skrivinger til loggfila.';
$strShowStatusInnodb_os_log_fsyncsDescr = 'Antall fsync-skrivinger utført på loggfila.';
$strShowStatusInnodb_os_log_pending_fsyncsDescr = 'Antall ventende loggfil-fsyncs.';
$strShowStatusInnodb_os_log_pending_writesDescr = 'Ventende loggfilskrivinger.';
$strShowStatusInnodb_os_log_writtenDescr = 'Antall bytes skrevet til loggfila.';
$strShowStatusInnodb_pages_createdDescr = 'Antall sider opprettet.';
$strShowStatusInnodb_page_sizeDescr = 'Den innkompilerte InnoDB sidestørrelsen (standard 16KB). Mange verdier måles i sider; sidestørrelsen gjør at det er lett å konvertere dem til bytes.';
$strShowStatusInnodb_pages_readDescr = 'Antall sidelesninger.';
$strShowStatusInnodb_pages_writtenDescr = 'Antall sideskrivinger.';
$strShowStatusInnodb_row_lock_current_waitsDescr = 'Antall ventende radlåsinger.';
$strShowStatusInnodb_row_lock_time_avgDescr = 'Gjennomsnittlig tid for å oppnå radlåsing, i millisekunder.';
$strShowStatusInnodb_row_lock_timeDescr = 'Total tid brukt for å få radlåsinger, i millisekunder.';
$strShowStatusInnodb_row_lock_time_maxDescr = 'Maksimum tid brukt for å oppnå en radlåsing, i millisekunder.';
$strShowStatusInnodb_row_lock_waitsDescr = 'Antall ganger en radlås måtte ventes på.';
$strShowStatusInnodb_rows_deletedDescr = 'Antall rader slettet fra InnoDB tabeller.';
$strShowStatusInnodb_rows_insertedDescr = 'Antall rader satt inn i InnoDB tabeller.';
$strShowStatusInnodb_rows_readDescr = 'Antall rader lest fra InnoDB tabeller.';
$strShowStatusInnodb_rows_updatedDescr = 'Antall rader oppdatert i InnoDB tabeller.';
$strShowStatusKey_blocks_not_flushedDescr = 'Antall nøkkelblokker i nøkkelmellomlageret som har blitt endret men som ikke ennå har blitt skrevet til harddisken. Dette var tidligere kjent som Not_flushed_key_blocks.';
$strShowStatusKey_blocks_unusedDescr = 'Antall ubrukte blokker i nøkkelmellomlageret. Du kan bruke denne verdien til å bestemme hvor mye av nøkkelmellomlageret som er i bruk.';
$strShowStatusKey_blocks_usedDescr = 'Antall brukte blokker i nøkkelmellomlageret. Denne verdien er et høyvannsmål som viser maksimum antall blokker som har vært brukt på en gang.';
$strShowStatusKey_read_requestsDescr = 'Antall forespørsler for å lese en nøkkelblokk fra mellomlageret.';
$strShowStatusKey_readsDescr = 'Antall fysiske lesninger av en nøkkelblokk fra harddisk. Hvis Key_reads er stor er nok din key_buffer_size verdi for liten. Mellomlagertreffraten kan kalkuleres med Key_reads/Key_read_requests.';
$strShowStatusKey_write_requestsDescr = 'Antall forespørsler for å skrive en nøkkelblokk til mellomlageret.';
$strShowStatusKey_writesDescr = 'Antall fysiske skrivinger av en nøkkelblokk til disk.';
$strShowStatusLast_query_costDescr = 'Den totale kostnad ved siste kompilerte spørring slik den ble utregnet av spørringsoptimisereren. Nyttig for å kunne sammenligne kostnader ved forskjellige spørringsplaner for den samme spørringen. Standardverdien på 0 betyr at ingen spørring har blitt kompilert ennå.';
$strShowStatusNot_flushed_delayed_rowsDescr = 'Antall rader som venter på å bli skrevet i INSERT DELAY køer.';
$strShowStatusOpened_tablesDescr = 'Antall tabeller som har blitt åpnet. Hvis denne er stor er nok din tabellmellomlagerverdi for liten.';
$strShowStatusOpen_filesDescr = 'Antall åpne filer.';
$strShowStatusOpen_streamsDescr = 'Antall åpne dataflyter (hovedsaklig brukt til logging).';
$strShowStatusOpen_tablesDescr = 'Antall åpne tabeller.';
$strShowStatusQcache_free_blocksDescr = 'Antall ledige minneblokker i spørringsmellomlager.';
$strShowStatusQcache_free_memoryDescr = 'Mengden ledig minne i spørringsmellomlager.';
$strShowStatusQcache_hitsDescr = 'Antall mellomlagertreff.';
$strShowStatusQcache_insertsDescr = 'Antall spørringer lagt til i mellomlageret.';
$strShowStatusQcache_lowmem_prunesDescr = 'Antall spørringer som har blitt fjernet fra mellomlageret for å frigjøre minne for nye spørringer. Denne informasjonen kan hjelpe deg å fininnstille størrelsen på spørringsmellomlageret. Spørringsmellomlageret bruker en minst og sist brukt (least recently used (LRU)) strategi for å finne hvilke spørringer som skal fjernes fra mellomlageret.';
$strShowStatusQcache_not_cachedDescr = 'Antallet ikkelagrede spørringer (kan ikke lagres, eller ikke lagret p.g.a. query_cache_type innstillingen).';
$strShowStatusQcache_queries_in_cacheDescr = 'Antall spørringer registrert i mellomlageret.';
$strShowStatusQcache_total_blocksDescr = 'Totale antall blokker i spørringsmellomlageret.';
$strShowStatusReset = 'Tilbakestill';
$strShowStatusRpl_statusDescr = 'Failsafe replikasjonsstatus (ikke implementert ennå).';
$strShowStatusSelect_full_joinDescr = 'Antall joins som ikke bruker indekser. Hvis denne verdien ikke er 0 bør du nøye sjekke indeksene til dine tabeller.';
$strShowStatusSelect_full_range_joinDescr = 'Antall joins som trenger en rekkefølgesøk i en referansetabell.';
$strShowStatusSelect_range_checkDescr = 'Antall joins uten nøkler som kontrollerer for nøkkelbruk etter hver rad (Hvis denne ikke er 0 bør du nøye kontrollere dine tabellindekser.)';
$strShowStatusSelect_rangeDescr = 'Antall joins som brukte rekkefølger på den første tabellen. (Det er normalt ikke kritisk selv om denne verdien er stor.)';
$strShowStatusSelect_scanDescr = 'Antall joins som utførte en full skann av den første tabellen.';
$strShowStatusSlave_open_temp_tablesDescr = 'Antall midlertidige tabeller for tiden åpnet av slave SQL tråden.';
$strShowStatusSlave_retried_transactionsDescr = 'Det totale antall ganger (siden oppstart) replikasjonsslave-SQL-tråden har gjentatt transaksjoner.';
$strShowStatusSlave_runningDescr = 'Denne er ON hvis denne tjeneren er en slave som er koblet til en master.';
$strShowStatusSlow_launch_threadsDescr = 'Antall tråder som har brukt mer enn slow_launch_time sekunder under opprettelse.';
$strShowStatusSlow_queriesDescr = 'Antall spørringer som har brukt mer enn long_query_time sekunder.';
$strShowStatusSort_merge_passesDescr = 'Antall sammenslåingspasseringer sorteringsalgoritmen har måttet utføre. Hvis denne verdien er stor bør du vurdere å øke verdien av sort_buffer_size systemvariabelen.';
$strShowStatusSort_rangeDescr = 'Antall sorteringer som ble utført med rekkefølger.';
$strShowStatusSort_rowsDescr = 'Antall sorterte rader.';
$strShowStatusSort_scanDescr = 'Antall sorteringer som har vært utført ved hjelp av skanning av tabellen.';
$strShowStatusTable_locks_immediateDescr = 'Antall ganger en tabellåsing ble utført umiddelbart.';
$strShowStatusTable_locks_waitedDescr = 'Antall ganger en tabellås ikke har kunnet blitt opprettet umiddelbart og en venting ble nødvendig. Hvis denne er høy og du har ytelsesproblemer bør du først optimalisere dine spørringer, og deretter enten splitte din tabell eller tabeller eller bruke replikasjon.';
$strShowStatusThreads_cachedDescr = 'Antall tråder i trådmellomlageret. Mellomlagertreffraten kan regnes ut som Threads_created/Connections. Hvis denne verdien er rød bør du øke din thread_cache_size.';
$strShowStatusThreads_connectedDescr = 'Antall åpne tilkoblinger.';
$strShowStatusThreads_createdDescr = 'Antall tråder opprettet for å handtere tilkoblinger. Hvis Threads_created er stor bør du vurdere å øke thread_cache_size størrelsen. (Normalt vil dette ikke gi noen merkbar forbedring hvis du har en god trådimplementering.)';
$strShowStatusThreads_runningDescr = 'Antall tråder som ikke sover.';
$strShowTableDimension = 'Vis tabelldimensjoner';
$strShowTables = 'Vis tabeller';
$strShowThisQuery = ' Vis denne spørring her igjen ';
$strShow = 'Vis';
$strSimplifiedChinese = 'forenklet kinesisk';
$strSingly = '(enkeltvis)';
$strSize = 'Størrelse';
$strSkipQueries = 'Antall poster(spørringer) å hoppe over fra start';
$strSlovak = 'Slovakisk';
$strSlovenian = 'Slovensk';
$strSocketProblem = '(eller den lokale MySQL tjenerens sokkel er ikke korrekt konfigurert)';
$strSortByKey = 'Sorter etter nøkkel';
$strSorting = 'Sortering';
$strSort = 'Sorter';
$strSpaceUsage = 'Plassbruk';
$strSpanish = 'Spansk';
$strSplitWordsWithSpace = 'Ord er separert med et mellomrom (" ").';
$strSQLCompatibility = 'SQL kompatibilitetsmodus';
$strSQLExportType = 'Eksporttype';
$strSQLImportOptions = 'SQL innstillinger';
$strSQLOptions = 'SQL valg';
$strSQLParserBugMessage = 'Det er en mulighet for at du har funnet en feil i SQL-parseren. Vennligst kontroller din spørring nøye og kontroller at anførselstegn er korrekte og matsjer hverandre. En annen mulig feilårsak kan være at du overfører en fil med binærkode som ikke ligger innenfor anførselstegn. Du kan også teste din spørring i MYSQLs kommandolinjegrensesnitt. Feilmeldingen fra MySQL-tjeneren nedenfor, hvis det var en, kan også hjelpe deg med å analysere problemet. Hvis du fortsatt har problemer eller parseren feiler hvor kommandolinjegrensesnittet lyktes, vennligst reduser din SQL-spørring til den spørringen som forårsaker problemet og send en feilrapport med datastykket i CUT-seksjonen nedenfor:';
$strSQLParserUserError = 'Det ser ut til å være en feil i din SQL-spørring. En eventuell feilmelding fra MySQL-tjeneren er skrevet ut nedenfor, kan kanskje hjelpe deg med å finne feilen.';
$strSQLQuery = 'SQL-spørring';
$strSQLResult = 'SQL-resultat';
$strSQL = 'SQL';
$strSQPBugInvalidIdentifer = 'Ugyldig identifikator';
$strSQPBugUnclosedQuote = 'Anførselstegnet er ikke lukket';
$strSQPBugUnknownPunctuation = 'Ukjent tegnsettingsstreng';
$strStatCheckTime = 'Sist kontrollert';
$strStatCreateTime = 'Opprettet';
$strStatement = 'Oversikt';
$strStatisticsOverrun = 'På en travel tjener så kan byte-tellerene overflyte, så denne statistikken som rapportert av MySQL tjeneren kan være unøyaktig.';
$strStatUpdateTime = 'Sist oppdatert';
$strStatus = 'Status';
$strStorageEngine = 'Lagringsmotor';
$strStorageEngines = 'Lagringsmotorer';
$strStrucCSV = 'CSV-data';
$strStrucData = 'Struktur og data';
$strStrucExcelCSV = 'CSV for MS Excel data';
$strStrucNativeExcelOptions = 'Excel eksportinnstillinger';
$strStrucNativeExcel = 'Originale MS Excel data';
$strStrucOnly = 'Kun struktur';
$strStructPropose = 'Foreslå tabellstruktur';
$strStructure = 'Struktur';
$strSubmit = 'Send';
$strSuccess = 'Kommandoen/spørringen er utført';
$strSum = 'Sum';
$strSwedish = 'svensk';
$strSwitchToDatabase = 'Bytt til kopiert database';
$strSwitchToTable = 'Bytt til kopiert tabell';

$strTableAlreadyExists = 'Tabel %s eksisterer allerede!';
$strTableComments = 'Tabellkommentarer';
$strTableEmpty = 'Tabellnavnet er tomt!';
$strTableHasBeenDropped = 'Tabellen %s har blitt slettet';
$strTableHasBeenEmptied = 'Tabellen %s har blitt tømt';
$strTableHasBeenFlushed = 'Tabelen %s har blitt oppfrisket';
$strTableMaintenance = 'Tabellvedlikehold';
$strTableOfContents = 'Innholdsfortegnelse';
$strTableOptions = 'Tabellinnstillinger';
$strTables = '%s tabell(er)';
$strTableStructure = 'Tabellstruktur for tabell';
$strTable = 'Tabell';
$strTakeIt = 'velg';
$strTblPrivileges = 'Tabell-spesifikke privilegier';
$strTempData = 'Midlertidige data';
$strTextAreaLength = ' På grunn av sin lengde,<br /> så vil muligens dette feltet ikke være redigerbart ';
$strThai = 'thai';
$strThemeDefaultNotFound = 'Standard stil %s ble ikke funnet!';
$strThemeNoPreviewAvailable = 'Ingen forhandsvisning tilgjengelig.';
$strThemeNotFound = 'Stilen %s ble ikke funnet!';
$strThemeNoValidImgPath = 'Ingen gyldig bildesti for stilen %s ble funnet!';
$strThemePathNotFound = 'Stilsti ble ikke funnet for stilen %s!';
$strTheme = 'Tema / Stil';
$strThisHost = 'Denne vert';
$strThisNotDirectory = 'Dette var ikke en katalog';
$strThreads = 'Tråder';
$strThreadSuccessfullyKilled = 'Tråd %s ble avsluttet med suksess.';
$strTimeoutInfo = 'Forrige import ble tidsavbrutt, vil fortsette fra posisjon %d etter gjenninnsending.';
$strTimeoutNothingParsed = 'Men under den siste kjøringen så ble ingen data lest, dette betyr vanligvis at phpMyAdmin ikke vil være istand til å fullføre importeringen uten at du øker php tidsgrensen.';
$strTimeoutPassed = 'Skripttidsabrudd passert, hvis du ønsker å fortsette importen kan du gjennopplaste fila og importeringen vil fortsette.';
$strTime = 'Tid';
$strToggleScratchboard = 'slå av/på kladdevindu';
$strTotal = 'totalt';
$strTotalUC = 'Totalt';
$strTraditionalChinese = 'Tradisjonell kinesisk';
$strTraditionalSpanish = 'Tradisjonell spansk';
$strTraffic = 'Trafikk';
$strTransactionCoordinator = 'Transaksjonskoordinator';
$strTransformation_application_octetstream__download = 'Vis en link for å kunne laste ned de binære dataene til et felt. Den første opsjonen er filnavnet til den binære fila. Den andre opsjonen er et potensielt feltnavn i en tabell som inneholder filnavnet. Hvis du velger den andre opsjonen så må den første være satt til en tom strengverdi';
$strTransformation_application_octetstream__hex ='Vis dataene i heksadesimal. Den valgfrie første parameteren tilkjennegir hvor ofte mellomrom vil bli lagt til (standard hvert andre tegn).';
$strTransformation_image_jpeg__inline = 'Viser et klikkbart tommelfingerbilde; valg: bredde, høyde i piksler (bevarer originale forhold)';
$strTransformation_image_jpeg__link = 'Viser en link til dette bildet (m.a.o. direkte blob-nedlasting).';
$strTransformation_image_png__inline = 'Se image/jpeg: inline';
$strTransformation_text_plain__dateformat = 'Tar et TIME, TIMESTAMP eller DATETIME felt og formaterer det med din lokale dato-/tidsformat. Første valg er avviket (i timer) som vil bli lagt til tidsformatet (Standard: 0). Andre valget er et annet dato-/tidsformat basert på parameterene til PHPs strftime().';
$strTransformation_text_plain__external = 'BARE LINUX: Starter et eksternt program og gir den feltdataene via standard input. Returnerer standart output fra programmet. Standard er Tidy, for å skrive ut pen HTML kode. Av sikkerhetsgrunner så må du redigere fila libraries/transformations/text_plain__external.inc.php og skrive inn de verktøyene du tillater å kjøres. Den første verdien er antall programmer du ønsker å bruke og den andre verdien er parameterene for programmet. Den tredje verdien, hvis den er satt til 1 vil konvertere utskriften med htmlspecialchars() (Standard er 1). En fjerde verdi vil, viss satt til 1 sette en NOWRAP i innholdscellen slik at hele resultatet blir vist uten reformatering (Standard er 1)';
$strTransformation_text_plain__formatted = 'Bevarer original formatering av feltet. Ingen \'escaping\' blir utført.';
$strTransformation_text_plain__imagelink = 'Viser et bilde og en link, feltet inneholder filnavnet; første verdi er et prefiks slik som "http://domain.com/", andre verdien er bredden i piksler, tredje er høyden.';
$strTransformation_text_plain__link = 'Viser en link, feltet inneholder filnavnet, ; første verdi er et prefiks slik som "http://domain.com/", andre verdien er en tittel for linken.';
$strTransformation_text_plain__sql = 'Formaterer tekst som en SQL spørring med syntaksutheving.';
$strTransformation_text_plain__substr = 'Viser bare en delstreng. Første verdien er antall tegn fra starten hvor din tekst begynner (Standard: 0). Andre verdien er hvor mange tegn som skal returneres. Hvis den er tom så returneres resten av teksten. Den tredje verdien definerer hvilke tegn som vil bli lagt til resultatet når en delstreng blir returnert (Standard: ...).';
$strTruncateQueries = 'Forkort vist spørring';
$strTurkish = 'tyrkisk';
$strType = 'Type';

$strUkrainian = 'ukrainsk';
$strUncheckAll = 'Fjern merking';
$strUnicode = 'Unicode';
$strUnique = 'Unik';
$strUnknown = 'ukjent';
$strUnselectAll = 'Fjern alle valgte';
$strUnsupportedCompressionDetected = 'Du forsøkte å laste en komprimert fil som det ikke er støtte for (%s). Enten så er ikke støtte implementert eller den er slått av i din konfigurasjon.';
$strUpdatePrivMessage = 'Du har oppdatert privilegiene til %s.';
$strUpdateProfileMessage = 'Profilen har blitt oppdatert.';
$strUpdateQuery = 'Oppdater spørring';
$strUpdComTab = 'Les i dokumentasjonen hvordan du oppdaterer din Column_comments tabell';
$strUpgrade = 'Du burde oppgradere til %s %s eller nyere.';
$strUploadLimit = 'Du forsøkte sansynligvis å laste opp en for stor fil. Sjekk %sdokumentasjonen%s for måter å omgå denne begrensningen.';
$strUploadsNotAllowed = 'Filopplastinger er ikke tillatt på denne tjeneren.';
$strUsage = 'Bruk';
$strUseBackquotes = 'Bruk venstre anførselstegn med tabell og feltnavn';
$strUsedPhpExtensions = 'Brukte PHP-tillegg';
$strUseHostTable = 'Vis vert tabell';
$strUserAlreadyExists = 'Brukeren %s finnes fra før!';
$strUser = 'Bruker';
$strUserEmpty = 'Brukernavnet er tomt!';
$strUserName = 'Brukernavn';
$strUserNotFound = 'Den valgte brukeren ble ikke funnet i privilegietabellen.';
$strUserOverview = 'Brukeroversikt';
$strUsersDeleted = 'De valgte brukerne har blitt slettet.';
$strUsersHavingAccessToDb = 'Brukere som har adgang til &quot;%s&quot;';
$strUseTabKey = 'Bruk TAB tasten for å flytte fra verdi til verdi, eller CTRL+piltastene for å bevege deg hvor som helst';
$strUseTables = 'Bruk tabeller';
$strUseTextField = 'Bruk tekstfelt';
$strUseThisValue = 'Bruk denne verdien';

$strValidateSQL = 'Test SQL';
$strValidatorError = 'SQL-kontrolleren kunne ikke startes. Vennligst sjekk at du har installert de nødvendige php-tilleggene som beskrevet i %sdokumentasjonen%s.';
$strValue = 'Verdi';
$strVar = 'Variabler';
$strVersionInformation = 'Versionsinformasjon';
$strViewDumpDatabases = 'Vis dumpet skjema av databaser';
$strViewDumpDB = 'Vis dump (skjema) av database';
$strViewDump = 'Vis dump (skjema) av tabell';
$strViewHasBeenDropped = 'Visningen %s har blitt slettet';
$strViewMaxExactCount = 'Denne visningen har mer enn %d rader. Les i %sdocumentation%s.';
$strView = 'Vis';

$strWebServerUploadDirectoryError = 'Katalogen du anga for opplasting kan ikke nåes';
$strWebServerUploadDirectory = 'webtjener opplastingskatalog';
$strWelcome = 'Velkommen til %s';
$strWestEuropean = 'vesteuropeisk';
$strWildcard = 'jokertegn';
$strWindowNotFound = 'Målvinduet kunne ikke oppdateres. Muligens du har lukket modervinduet eller din nettleser blokkerer vindu-til-vindu oppdateringer av sikkerhetsårsaker.';
$strWithChecked = 'Med avkrysset:';
$strWriteRequests = 'Skriveforespørsler';
$strWritingCommentNotPossible = 'Skriving av kommentar er ikke mulig';
$strWritingRelationNotPossible = 'Skriving av relasjon er ikke mulig';
$strWrongUser = 'Ugyldig brukernavn/passord. Ingen tilgang.';

$strXMLOptions = 'XML innstillinger';
$strXML = 'XML';

$strYes = 'Ja';

$strZeroRemovesTheLimit = 'Merk: Ved å sette disse til 0 (null) fjernes begrensningen.';
$strZip = 'Komprimert (zip)';

?>
